@@ -3,10 +3,10 @@
 
     void printperson(Person const &p)
     {
-        cout << "Name    : " << p.name()     << endl <<
-                "Address : " << p.address()  << endl <<
-                "Phone   : " << p.phone()    << endl <<
-                "Weight  : " << p.weight()   << endl;
+        cout << "Name    : " << p.name()     << "\n"
+                "Address : " << p.address()  << "\n"
+                "Phone   : " << p.phone()    << "\n"
+                "Mass  : " << p.mass()   << '\n';
     }
 
     int main()
@@ -16,10 +16,9 @@
         p.setName("Linus Torvalds");
         p.setAddress("E-mail: Torvalds@cs.helsinki.fi");
         p.setPhone(" - not sure - ");
-        p.setWeight(75);           // kg.
+        p.setMass(75);           // kg.
 
         printperson(p);
-        return 0;
     }
 /*
     Produced output:
@@ -27,6 +26,6 @@
 Name    : Linus Torvalds
 Address : E-mail: Torvalds@cs.helsinki.fi
 Phone   :  - not sure -
-Weight  : 75
+Mass  : 75
 
 */
