@@ -21,7 +21,7 @@ class Vector2: public std::vector<std::vector<Type> >
         {
             FBB::ForEach(row.begin(), row.end(), this,
                                                 &Vector2<Type>::columns);
-            std::cout << std::endl;
+            std::cout << '\n';
         }
         void columns(Type &str)
         {
