@@ -2,18 +2,21 @@
     using namespace std;
 
     int main(int argc, char **argv)
+    try
     {
         if (argc == 1)
         {
             cerr << "Filename argument required\n";
-            exit (1);
+            return 1;
         }
+
         ifstream yyin(argv[1]);
         if (!yyin)
         {
-            cerr << "Can't read " << argv[1] << endl;
-            exit(1);
+            cerr << "Can't read " << argv[1] << '\n';
+            return 1;
         }
+
         Scanner scanner(&yyin, argv[1]);
         try
         {
@@ -29,9 +32,8 @@
                 "Read",
             };
             cerr << msg[err] << " error in " << scanner.lastFile() <<
-                                ", line " << scanner.lineno() << endl;
+                                ", line " << scanner.lineno() << '\n';
             scanner.stackTrace();
             return 1;
         }
-        return 0;
     }
