@@ -23,7 +23,7 @@
     {
         pair<string, MyClass> pairs[] =
         {
-            pair<string, MyClass>("one", MyClass()),
+            pair<string, MyClass>("one", MyClass())
         };
         cout << "pairs constructed\n";
 
@@ -41,4 +41,5 @@
     MyClass destructor
     mapsm constructed
     MyClass destructor
+    MyClass destructor
     */
