@@ -4,6 +4,8 @@
 
     using namespace std;
 
+    jmp_buf jmpBuf;
+
     class Inner
     {
         public:
@@ -12,6 +14,20 @@
             void fun();
     };
 
+    Inner::Inner()
+    {
+        cout << "Inner constructor\n";
+    }
+    void Inner::fun()
+    {
+        cout << "Inner fun\n";
+        longjmp(jmpBuf, 0);
+    }
+    Inner::~Inner()
+    {
+        cout << "Inner destructor\n";
+    }
+
     class Outer
     {
         public:
@@ -20,38 +36,17 @@
             void fun();
     };
 
-    jmp_buf jmpBuf;
-
-    Inner::Inner()
-    {
-        cout << "Inner constructor\n";
-    }
-
-    void Inner::fun()
-    {
-        cout << "Inner fun()\n";
-        longjmp(jmpBuf, 0);
-    }
-
-    Inner::~Inner()
-    {
-        cout << "Inner destructor\n";
-    }
-
     Outer::Outer()
     {
         cout << "Outer constructor\n";
     }
-
     Outer::~Outer()
     {
         cout << "Outer destructor\n";
     }
-
     void Outer::fun()
     {
         Inner in;
-
         cout << "Outer fun\n";
         in.fun();
     }
@@ -60,18 +55,16 @@
     {
         Outer out;
 
-        if (!setjmp(jmpBuf))
-        {
-            out.fun();
-            return 0;
-        }
-        return 1;
+        if (setjmp(jmpBuf) != 0)
+            return 1;
+
+        out.fun();
     }
     /*
         Generated output:
     Outer constructor
     Inner constructor
     Outer fun
-    Inner fun()
+    Inner fun
     Outer destructor
     */
