@@ -20,6 +20,6 @@
             )
                 continue;
 
-            opb << line << endl;
+            opb << line << '\n';
         }
     }
