@@ -8,4 +8,4 @@
             Binary &operator+=(Binary const &other);
     };
 
-    Binary const operator+(Binary const &l_hand, Binary const &r_hand);
+    Binary const operator+(Binary const &lhs, Binary const &rhs);
