@@ -1,19 +1,19 @@
     class PointerDemo
     {
         public:
-            unsigned d_value;
-            unsigned get() const;
+            size_t d_value;
+            size_t get() const;
     };
 
-    inline unsigned PointerDemo::get() const
+    inline size_t PointerDemo::get() const
     {
         return d_value;
     }
 
     int main()
     {                                           // initialization
-        unsigned (PointerDemo::*getPtr)() const = &PointerDemo::get;
-        unsigned PointerDemo::*valuePtr         = &PointerDemo::d_value;
+        size_t (PointerDemo::*getPtr)() const = &PointerDemo::get;
+        size_t PointerDemo::*valuePtr         = &PointerDemo::d_value;
 
         getPtr   = &PointerDemo::get;           // assignment
         valuePtr = &PointerDemo::d_value;
